@@ -3,7 +3,9 @@
 
 #define FAST_BUILD
 #define ZLIB_FOUND
-/* #undef CUPDLP_CPU */
+#define CUPDLP_CPU
+/* #undef CUPDLP_GPU */
+/* #undef CUPDLP_FORCE_NATIVE */
 #define CMAKE_BUILD_TYPE "Release"
 #define CMAKE_INSTALL_PREFIX "/clangarm64"
 /* #undef HIGHSINT64 */
@@ -14,8 +16,8 @@
 
 #define HIGHS_GITHASH "n/a"
 #define HIGHS_VERSION_MAJOR 1
-#define HIGHS_VERSION_MINOR 9
+#define HIGHS_VERSION_MINOR 10
 #define HIGHS_VERSION_PATCH 0
-#define HIGHS_DIR "C:/M/B/src/HiGHS-1.9.0"
+#define HIGHS_DIR "C:/M/B/src/HiGHS-1.10.0"
 
 #endif /* HCONFIG_H_ */
